@@ -233,7 +233,6 @@ bool nsWindow::OnPaint(HDC aDC, uint32_t aNestingLevel)
 
   PAINTSTRUCT ps;
 
-#ifdef MOZ_XUL
   if (!aDC && (eTransparencyTransparent == mTransparencyMode))
   {
     // For layered translucent windows all drawing should go to memory DC and no
@@ -248,7 +247,6 @@ bool nsWindow::OnPaint(HDC aDC, uint32_t aNestingLevel)
     // We're guaranteed to have a widget proxy since we called GetLayerManager().
     aDC = mCompositorWidgetDelegate->GetTransparentDC();
   }
-#endif
 
   mPainting = true;
 
@@ -267,11 +265,7 @@ bool nsWindow::OnPaint(HDC aDC, uint32_t aNestingLevel)
   HDC hDC = aDC ? aDC : (::BeginPaint(mWnd, &ps));
   mPaintDC = hDC;
 
-#ifdef MOZ_XUL
   bool forceRepaint = aDC || (eTransparencyTransparent == mTransparencyMode);
-#else
-  bool forceRepaint = nullptr != aDC;
-#endif
   nsIntRegion region = GetRegionToPaint(forceRepaint, ps, hDC);
 
   if (clientLayerManager) {
@@ -317,14 +311,12 @@ bool nsWindow::OnPaint(HDC aDC, uint32_t aNestingLevel)
         {
           RefPtr<gfxASurface> targetSurface;
 
-#if defined(MOZ_XUL)
           // don't support transparency for non-GDI rendering, for now
           if (eTransparencyTransparent == mTransparencyMode) {
             // This mutex needs to be held when EnsureTransparentSurface is called.
             MutexAutoLock lock(mBasicLayersSurface->GetTransparentSurfaceLock());
             targetSurface = mBasicLayersSurface->EnsureTransparentSurface();
           }
-#endif
 
           RefPtr<gfxWindowsSurface> targetSurfaceWin;
           if (!targetSurface)
@@ -353,7 +345,6 @@ bool nsWindow::OnPaint(HDC aDC, uint32_t aNestingLevel)
 
           // don't need to double buffer with anything but GDI
           BufferMode doubleBuffering = mozilla::layers::BufferMode::BUFFER_NONE;
-#ifdef MOZ_XUL
           switch (mTransparencyMode) {
             case eTransparencyGlass:
             case eTransparencyBorderlessGlass:
@@ -368,9 +359,6 @@ bool nsWindow::OnPaint(HDC aDC, uint32_t aNestingLevel)
                                  dt->GetSize().width, dt->GetSize().height));
               break;
           }
-#else
-          doubleBuffering = mozilla::layers::BufferMode::BUFFERED;
-#endif
 
           RefPtr<gfxContext> thebesContext = gfxContext::CreateOrNull(dt);
           MOZ_ASSERT(thebesContext); // already checked draw target above
@@ -382,14 +370,12 @@ bool nsWindow::OnPaint(HDC aDC, uint32_t aNestingLevel)
               this, LayoutDeviceIntRegion::FromUnknownRegion(region));
           }
 
-#ifdef MOZ_XUL
           if (eTransparencyTransparent == mTransparencyMode) {
             // Data from offscreen drawing surface was copied to memory bitmap of transparent
             // bitmap. Now it can be read from memory bitmap to apply alpha channel and after
             // that displayed on the screen.
             mBasicLayersSurface->RedrawTransparentWindow();
           }
-#endif
         }
         break;
       case LayersBackend::LAYERS_CLIENT:
